@@ -151,14 +151,14 @@ sbp.fromPBA <- function(x, alpha = NA){
   sbp.fromHclust(h)
 }
 
-#' Build SBP Matrix of "Anti-Balances"
+#' Build SBP Matrix of "Anti-Principal Balances"
 #'
-#' This function builds an SBP of "anti-balances" by clustering
-#'  the difference of the log-ratio variance from the
-#'  maximum log-ratio variance. Unlike principal balances,
+#' This function builds an SBP of "anti-principal balances"
+#'  by clustering the difference of the log-ratio variance from
+#'  the maximum log-ratio variance. Unlike principal balances,
 #'  where the first balances explain the most variance,
-#'  this function selects "anti-balances" so that the
-#'  last balances explain the most variance.
+#'  this function selects "anti-principal balances" so that
+#'  the last balances explain relatively more variance.
 #'
 #' @inheritParams vlr
 #'
@@ -180,14 +180,14 @@ sbp.fromABA <- function(x, alpha = NA){
   sbp.fromHclust(h)
 }
 
-#' Build SBP Matrix of "Anti-Balances"
+#' Build SBP Matrix of "Principal Discriminant Balances"
 #'
-#' This function builds an SBP of "anti-balances" by clustering
-#'  the difference of the log-ratio variance from the
-#'  maximum log-ratio variance. Unlike principal balances,
-#'  where the first balances explain the most variance,
-#'  this function selects "anti-balances" so that the
-#'  last balances explain the most variance.
+#' This function builds an SBP of "discriminant balances"
+#'  by clustering a matrix of the pair-wise total within-group
+#'  variance, adjusted by the pair-wise total variance
+#'  (inverted by subtracting this value from 1).
+#'  The method is intended to make the largest balances
+#'  most discriminative.
 #'
 #' @inheritParams vlr
 #' @param group A character vector. Group or sub-group membership.
@@ -202,19 +202,80 @@ sbp.fromABA <- function(x, alpha = NA){
 #' \dontrun{
 #' library(balance)
 #' data(iris)
-#' x <- iris[,1:4]
-#' sbp.fromPropd(x)
+#' x <- iris[1:100,1:4]
+#' y <- iris[1:100,5]
+#' sbp.fromPDBA(x, y)
+#' }
+#'
+#' @export
+sbp.fromPDBA <- function(x, group, ...){
+
+  packageCheck("propr")
+
+  pd <- suppressMessages(propr::propd(x, group, ...))
+  theta <- propr::getMatrix(pd)
+  h <- stats::hclust(stats::as.dist(1 - theta))
+  sbp.fromHclust(h)
+}
+
+#' Build SBP Matrix of "Anti-Principal Discriminant Balances"
+#'
+#' This function builds an SBP of "discriminant balances"
+#'  by clustering a matrix of the pair-wise total within-group
+#'  variance, adjusted by the pair-wise total variance.
+#'  The method is intended to make the smallest balances
+#'  most discriminative.
+#'
+#' @inheritParams sbp.fromPDBA
+#'
+#' @return An SBP matrix.
+#'
+#' @author Thom Quinn
+#'
+#' @examples
+#' \dontrun{
+#' library(balance)
+#' data(iris)
+#' x <- iris[1:100,1:4]
+#' y <- iris[1:100,5]
+#' sbp.fromADBA(x, y)
+#' }
+#'
+#' @export
+sbp.fromADBA <- function(x, group, ...){
+
+  packageCheck("propr")
+
+  pd <- suppressMessages(propr::propd(x, group, ...))
+  theta <- propr::getMatrix(pd)
+  h <- stats::hclust(stats::as.dist(theta))
+  sbp.fromHclust(h)
+}
+
+#' Build SBP Matrix of "Anti-Principal Discriminant Balances"
+#'
+#' A wrapper for \code{\link{sbp.fromADBA}}.
+#'  See also \code{\link{sbp.fromPDBA}}.
+#'
+#' @inheritParams sbp.fromPDBA
+#'
+#' @return An SBP matrix.
+#'
+#' @author Thom Quinn
+#'
+#' @examples
+#' \dontrun{
+#' library(balance)
+#' data(iris)
+#' x <- iris[1:100,1:4]
+#' y <- iris[1:100,5]
+#' sbp.fromPropd(x, y)
 #' }
 #'
 #' @export
 sbp.fromPropd <- function(x, group, ...){
 
-  packageCheck("propr")
-
-  pd <- propr::propd(x, group, ...)
-  theta <- propr::getMatrix(pd)
-  h <- stats::hclust(stats::as.dist(theta))
-  sbp.fromHclust(h)
+  sbp.fromADBA(x, group, ...)
 }
 
 #' Sort SBP Matrix
